pro return_masked_pixels, mask, bits, ptr, mcount
;+
; PURPOSE:
;    To return a pointer containing the pixels masked out by the supplied
;    mask.
; INPUTS:
;    MASK: 2d array containing pixel mask, should be long, int or byte
;    BITS: mask bits to use
; OUTPUTS:
;    PTR: long vector which is a pointer to the pixels in the mask which
;    contain the one or more of the desired bits
;    MCOUNT: number of flagged pixels
; HISTORY:
;    July 2004 SJC code written
;    01 Sep 2004 SJC removed duplicates in PTR
;    26 April 2005 SJC corrected number of pixels returned
;    27 April 2005 SJC fixed bug in removing duplicated indices
;-
	nbits = n_elements(bits)
	mand = 2L^bits
	ptr = [-1L]
	for i = 0, nbits-1 do begin
		mptr = where(mask and mand[i], mcount)
		if (mcount gt 0) then ptr = [ptr, mptr]
	endfor
	mcount = n_elements(ptr)
	if (mcount gt 1) then begin
; Remove duplicated indices
		bptr = bsort(ptr)
		ptr = ptr[bptr]
		bptr = uniq(ptr)
		ptr = ptr[bptr]
; Truncate initial element
		ptr = ptr[1:*]
	endif 
; Recount number of flagged pixels
	mcount = n_elements(ptr)
return
end
