pro return_valid_pixels, im, mask, max_flux=max_flux, min_flux=min_flux

; Return basic bad-pixel masks for 24 or 70 micron BCDs,
; and also flag pixels that are NaNs in the image.

sz = size(im)
nx = sz[1]
ny = sz[2]

if (nx eq 128) then begin
    ; default bad pixels for 24 micron array
    wbad = [3183,10804,10931,10932,10933,11059,11060,11061,11188,12772,12899, $
          12900,12901,13028,16128,16129,16130,16256,16257,16258,16259,16297]
    wbadc = n_elements(wbad)
end else begin
    wbad = [-1]
    wbadc = 0
endelse

mask = bytarr(nx,ny) + 1B

if (wbadc gt 0) then mask(wbad) = 0B

; wnan = wherenan(im,wnanc)
wnan = where(im ne im,wnanc) ; 07DEC2006 DRM
if (wnanc gt 0) then mask(wnan) = 0B

if (nx eq 128) then begin
    ; flag negative values as bad.
    wneg = where(im lt 0.,wnegc)
    if (wnegc gt 0) then mask(wneg) = 0B
endif

if (nx eq 32) then begin
    ; 09MAR2007 DRM, basic 70 micron bad-pixel mask.
    mask[16:*,*] = 0B
    mask[12:15,0:7] = 0B
    mask[3,28] = 0B
endif

if (keyword_set(max_flux)) then begin
    wmax = where(im gt max_flux,wmaxc)
    if (wmaxc gt 0) then mask(wmax) = 0B
endif

if (keyword_set(min_flux)) then begin
    wmin = where(im lt min_flux,wminc)
    if (wminc gt 0) then mask(wmin) = 0B
endif

end

